diff --git a/src/_zkapauthorizer/tests/test_client_resource.py b/src/_zkapauthorizer/tests/test_client_resource.py
index 46d2f5702cc1933313d3681963440df9e3f432b6..410d78cb2405f150757dcfa7ec9efeda5f29c249 100644
--- a/src/_zkapauthorizer/tests/test_client_resource.py
+++ b/src/_zkapauthorizer/tests/test_client_resource.py
@@ -230,21 +230,21 @@ class ResourceTests(TestCase):
         )
 
 
-class BlindedTokenTests(TestCase):
+class UnblindedTokenTests(TestCase):
     """
     Tests relating to ``/blinded-token`` as implemented by the
     ``_zkapauthorizer.resource`` module.
     """
     def setUp(self):
-        super(BlindedTokenTests, self).setUp()
+        super(UnblindedTokenTests, self).setUp()
         self.useFixture(CaptureTwistedLogs())
 
 
     @given(tahoe_configs(), vouchers(), integers(min_value=0, max_value=100))
     def test_get(self, get_config, voucher, num_tokens):
         """
         When the blinded token collection receives a **GET**, the response is the
         total number of blinded tokens in the system and the blinded tokens
         themselves.
         """
         tempdir = self.useFixture(TempDir())
@@ -230,21 +230,21 @@ class ResourceTests(TestCase):
     """
-    Tests relating to ``/blinded-token`` as implemented by the
+    Tests relating to ``/unblinded-token`` as implemented by the
     ``_zkapauthorizer.resource`` module.
     """
@@ -230,21 +230,21 @@ class ResourceTests(TestCase):
     def test_get(self, get_config, voucher, num_tokens):
         """
-        When the blinded token collection receives a **GET**, the response is the
-        total number of blinded tokens in the system and the blinded tokens
+        When the unblinded token collection receives a **GET**, the response is the
+        total number of unblinded tokens in the system and the unblinded tokens
         themselves.
         """